'use strict';

const Promise = require('bluebird');
const wk = require('../../config/wikidot-kit');
const sentry = require('../../lib/sentry');
const pino = require('../../lib/pino');
const db = require('../../config/db');

module.exports = () => {
    pino.info('Performing pages lists import');
    const promises = [];

    wk.wikiList
        .filter(({interwiki}) => interwiki)
        .forEach(({name}) => {
            const promise = wk.fetchPagesList({wiki: name})
                .then((list) => {
                    return db.query(`
                        INSERT INTO wikidot_pages_lists (wiki, data)
                        VALUES($(name), $(list))
                        ON CONFLICT (wiki) DO UPDATE SET
                            data = $(list)
                    `, {name, list: {list}}).then(() => {
                        pino.info(`Pages list for wiki ${name} updated`);
                    });
                })
                .catch((error) => {
                    pino.error(error, 'Error occured during pages list import', {wiki: name});
                    sentry.captureException(error, {extra: {wiki: name}});
                })
                .then(() => '');

            promises.push(promise);
        });

    return Promise.all(promises);
};
