'use strict';

const sentry = require('../../lib/sentry');
const pino = require('../../lib/pino');
const wk = require('../../config/wikidot-kit');
const db = require('../../config/db');

module.exports = async function importPageVotes({wikiName, pageName}) {
    const wiki = wk.wiki[wikiName];
    const wikiURL = wiki.url;
    const votes = await wk.fetchPageVotes({wikiURL, pageName});

    return db.query(`
        INSERT INTO pages (name, wiki, votes) VALUES ($(name), $(wiki), $(votes))
        ON CONFLICT (name, wiki) DO UPDATE SET votes = $(votes);
    `, {name: pageName, wiki: wiki.name, votes: {votes}})
        .catch((error) => {
            pino.error(error, 'Error saving page votes');
            sentry.captureException(error, {extra: {wiki: wikiName, name: pageName}});
        });
};
