'use strict';

const pino = require('./pino');
const Sentry = require('raven');
const SENTRY_DSN = process.env.SCPNET_SENTRY_DSN || process.env.SENTRY_DSN;
const VERSION = require('../package.json').version;

let sentry;

if (SENTRY_DSN) {
    Sentry.config(SENTRY_DSN, {release: VERSION}).install();
    sentry = Sentry;

    sentry.captureException = sentry.captureException.bind(sentry);
    sentry.captureMessage = sentry.captureMessage.bind(sentry);
} else {
    sentry = {
        captureMessage: () => {},
        captureException: () => {},

        requestHandler: () => (req, res, next) => next(),
        errorHandler: () => (err, req, res, next) => next(err)
    };
}

sentry.logError = ({message, error, meta = {}}) => {
    pino.error(error, message);
    meta.extra = Object.assign({}, {message}, meta.extra);
    sentry.captureException(error, meta);
};

module.exports = sentry;
